## Variant effect scores

- [ ] describe how these relate to the yaml file

## Available scores

<span style="float:right;">[[source]](https://github.com/kipoi/kipoi/blob/master/kipoi/postprocessing/variant_effects.py#L46)</span>
### Logit

```python
kipoi.postprocessing.variant_effects.Logit(rc_merging='max')
```

----

<span style="float:right;">[[source]](https://github.com/kipoi/kipoi/blob/master/kipoi/postprocessing/variant_effects.py#L60)</span>
### LogitAlt

```python
kipoi.postprocessing.variant_effects.LogitAlt(rc_merging='max')
```

----

<span style="float:right;">[[source]](https://github.com/kipoi/kipoi/blob/master/kipoi/postprocessing/variant_effects.py#L74)</span>
### LogitRef

```python
kipoi.postprocessing.variant_effects.LogitRef(rc_merging='max')
```

----

<span style="float:right;">[[source]](https://github.com/kipoi/kipoi/blob/master/kipoi/postprocessing/variant_effects.py#L74)</span>
### LogitRef

```python
kipoi.postprocessing.variant_effects.LogitRef(rc_merging='max')
```

----

<span style="float:right;">[[source]](https://github.com/kipoi/kipoi/blob/master/kipoi/postprocessing/variant_effects.py#L88)</span>
### Diff

```python
kipoi.postprocessing.variant_effects.Diff(rc_merging='max')
```

----

<span style="float:right;">[[source]](https://github.com/kipoi/kipoi/blob/master/kipoi/postprocessing/variant_effects.py#L100)</span>
### DeepSEA_effect

```python
kipoi.postprocessing.variant_effects.DeepSEA_effect(rc_merging='max')
```

